@@ -1,8 +1,8 @@
 module System.Log.FastLogger.Types (
-  -- * Types
-    TimeFormat
-  , FormattedTime
-  ) where
+    -- * Types
+    TimeFormat,
+    FormattedTime,
+) where
 
 import System.Log.FastLogger.Imports
 
@@ -10,4 +10,5 @@ import System.Log.FastLogger.Imports
 
 -- | Type aliaes for date format and formatted date.
 type FormattedTime = ByteString
+
 type TimeFormat = ByteString
